@@ -1943,6 +1943,7 @@ class DescribeStatementSegment(BaseSegment):
                     Ref("StatementSegment"),
                 ),
             ),
+            exclude=Ref.keyword("HISTORY"),
         ),
     )
 
@@ -2229,6 +2230,9 @@ class StatementSegment(ansi.StatementSegment):
             # Data Retrieval Statements
             Ref("ClusterByClauseSegment"),
             Ref("DistributeByClauseSegment"),
+            # Delta Lake
+            Ref("VacuumStatementSegment"),
+            Ref("DescribeHistoryStatementSegment"),
         ],
         remove=[
             Ref("TransactionStatementSegment"),
@@ -2608,3 +2612,53 @@ class IntervalExpressionSegment(ansi.IntervalExpressionSegment):
             Ref("QuotedLiteralSegment"),
         ),
     )
+
+
+class VacuumStatementSegment(BaseSegment):
+    """A `VACUUM` statement segment.
+
+    https://docs.delta.io/latest/delta-utility.html#remove-files-no-longer-referenced-by-a-delta-table
+    """
+
+    type = "vacuum_statement"
+
+    match_grammar: Matchable = Sequence(
+        "VACUUM",
+        OneOf(
+            Ref("QuotedLiteralSegment"),
+            Ref("FileReferenceSegment"),
+            Ref("TableReferenceSegment"),
+        ),
+        OneOf(
+            Sequence(
+                "RETAIN",
+                Ref("NumericLiteralSegment"),
+                Ref("DatetimeUnitSegment"),
+            ),
+            Sequence(
+                "DRY",
+                "RUN",
+            ),
+            optional=True,
+        ),
+    )
+
+
+class DescribeHistoryStatementSegment(BaseSegment):
+    """A `DESCRIBE HISTORY` statement segment.
+
+    https://docs.delta.io/latest/delta-utility.html#retrieve-delta-table-history
+    """
+
+    type = "describe_history_statement"
+
+    match_grammar: Matchable = Sequence(
+        "DESCRIBE",
+        "HISTORY",
+        OneOf(
+            Ref("QuotedLiteralSegment"),
+            Ref("FileReferenceSegment"),
+            Ref("TableReferenceSegment"),
+        ),
+        Ref("LimitClauseSegment", optional=True),
+    )
